package
Version:
v0.0.0-...-e7b4219
Opens a new window with list of versions in this module.
Published: Jun 7, 2020
License: GPL-3.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Configure(engine *gorm.DB)
type RestAPIs struct {
Bean interface{}
Beans interface{}
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.